#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_LOOKUP_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_LOOKUP_HPP_INCLUDED

#include <boost/simd/swar/include/functions/lookup.hpp>

#endif
